==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/ALERTTEXTPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ALERTTEXTPARAMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ALERTTEXTPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TEXTPARAMETERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARAMETERNUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAILTEMPLATEID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTTEXTPARAMETERID_Type", propOrder = {
    "alertid",
    "textparametertype",
    "parameternumber",
    "mailtemplateid"
})
public class ALERTTEXTPARAMETERID_Type {

    @XmlElement(name = "ALERTID", required = true)
    protected ALERTID_Type alertid;
    @XmlElement(name = "TEXTPARAMETERTYPE", required = true)
    protected String textparametertype;
    @XmlElement(name = "PARAMETERNUMBER")
    protected long parameternumber;
    @XmlElement(name = "MAILTEMPLATEID")
    protected MAILTEMPLATEID_Type mailtemplateid;

    /**
     * Obtient la valeur de la propriété alertid.
     * 
     * @return
     *     possible object is
     *     {@link ALERTID_Type }
     *     
     */
    public ALERTID_Type getALERTID() {
        return alertid;
    }

    /**
     * Définit la valeur de la propriété alertid.
     * 
     * @param value
     *     allowed object is
     *     {@link ALERTID_Type }
     *     
     */
    public void setALERTID(ALERTID_Type value) {
        this.alertid = value;
    }

    /**
     * Obtient la valeur de la propriété textparametertype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTEXTPARAMETERTYPE() {
        return textparametertype;
    }

    /**
     * Définit la valeur de la propriété textparametertype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTEXTPARAMETERTYPE(String value) {
        this.textparametertype = value;
    }

    /**
     * Obtient la valeur de la propriété parameternumber.
     * 
     */
    public long getPARAMETERNUMBER() {
        return parameternumber;
    }

    /**
     * Définit la valeur de la propriété parameternumber.
     * 
     */
    public void setPARAMETERNUMBER(long value) {
        this.parameternumber = value;
    }

    /**
     * Obtient la valeur de la propriété mailtemplateid.
     * 
     * @return
     *     possible object is
     *     {@link MAILTEMPLATEID_Type }
     *     
     */
    public MAILTEMPLATEID_Type getMAILTEMPLATEID() {
        return mailtemplateid;
    }

    /**
     * Définit la valeur de la propriété mailtemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link MAILTEMPLATEID_Type }
     *     
     */
    public void setMAILTEMPLATEID(MAILTEMPLATEID_Type value) {
        this.mailtemplateid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/ALERTTEXTPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALERTTEXTPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ALERTTEXTPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TEXTPARAMETERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARAMETERNUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAILTEMPLATEID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTTEXTPARAMETERID_Type", propOrder = {
    "alertid",
    "textparametertype",
    "parameternumber",
    "mailtemplateid"
})
public class ALERTTEXTPARAMETERID_Type {

    @XmlElement(name = "ALERTID", required = true)
    protected ALERTID_Type alertid;
    @XmlElement(name = "TEXTPARAMETERTYPE", required = true)
    protected String textparametertype;
    @XmlElement(name = "PARAMETERNUMBER")
    protected long parameternumber;
    @XmlElement(name = "MAILTEMPLATEID")
    protected MAILTEMPLATEID_Type mailtemplateid;

    /**
     * Gets the value of the alertid property.
     * 
     * @return
     *     possible object is
     *     {@link ALERTID_Type }
     *     
     */
    public ALERTID_Type getALERTID() {
        return alertid;
    }

    /**
     * Sets the value of the alertid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ALERTID_Type }
     *     
     */
    public void setALERTID(ALERTID_Type value) {
        this.alertid = value;
    }

    /**
     * Gets the value of the textparametertype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTEXTPARAMETERTYPE() {
        return textparametertype;
    }

    /**
     * Sets the value of the textparametertype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTEXTPARAMETERTYPE(String value) {
        this.textparametertype = value;
    }

    /**
     * Gets the value of the parameternumber property.
     * 
     */
    public long getPARAMETERNUMBER() {
        return parameternumber;
    }

    /**
     * Sets the value of the parameternumber property.
     * 
     */
    public void setPARAMETERNUMBER(long value) {
        this.parameternumber = value;
    }

    /**
     * Gets the value of the mailtemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link MAILTEMPLATEID_Type }
     *     
     */
    public MAILTEMPLATEID_Type getMAILTEMPLATEID() {
        return mailtemplateid;
    }

    /**
     * Sets the value of the mailtemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MAILTEMPLATEID_Type }
     *     
     */
    public void setMAILTEMPLATEID(MAILTEMPLATEID_Type value) {
        this.mailtemplateid = value;
    }

}
